@@ -1,5 +1,6 @@
 from fastapi import APIRouter, Depends
 
+from fief.crypto.id_token import get_user_claims
 from fief.fastapi_users import current_active_user
 from fief.schemas.user import UserDB
 
@@ -8,8 +9,7 @@ router = APIRouter()
 
 @router.get("/userinfo", name="user:userinfo.get")
 async def get_userinfo(user: UserDB = Depends(current_active_user)):
-    user_claims = user.get_claims()
-    return user_claims
+    return get_user_claims(user)
 
 
 # OpenID specification requires the /userinfo endpoint
@@ -17,5 +17,4 @@ async def get_userinfo(user: UserDB = Depends(current_active_user)):
 # https://openid.net/specs/openid-connect-core-1_0.html#UserInfoRequest
 @router.post("/userinfo", name="user:userinfo.post")
 async def post_userinfo(user: UserDB = Depends(current_active_user)):
-    user_claims = user.get_claims()
-    return user_claims
+    return get_user_claims(user)
